// code block colors
$btn-code-copy-color: if(
  variable-exists(text-muted),
  $text-muted,
  $body-color
) !default;

$btn-code-copy-color-active: if(
  variable-exists(link-color),
  $link-color,
  #0d6efd
) !default;
